# Entity

Entities in Ftrack are represented as classes within the `trackteroid` module, and they serve various purposes, including the following:

- [Querying](query.md#query)
- [Collection Filtering](collections.md#type-filtering)
- [Type Coercion](collections.md#type-coercion)